{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-i"
                    },
                    "doc": "Input BAM file to be converted to BED format",
                    "id": "#bedtools-bamtobed.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed12"
                    },
                    "doc": "Write \"blocked\" BED format (aka \"BED12\"). Forces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/bed12"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bedpe"
                    },
                    "doc": "Write BEDPE format.\n- Requires BAM to be grouped or sorted by query.\n",
                    "id": "#bedtools-bamtobed.cwl/bedpe"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-cigar"
                    },
                    "doc": "Add the CIGAR string to the BED entry as a 7th column.\n",
                    "id": "#bedtools-bamtobed.cwl/cigar"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-color"
                    },
                    "doc": "An R,G,B string for the color used with BED12 format.\nDefault is (255,0,0).\n",
                    "id": "#bedtools-bamtobed.cwl/color"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ed"
                    },
                    "doc": "Use BAM edit distance (NM tag) for BED score.\n- Default for BED is to use mapping quality.\n- Default for BEDPE is to use the minimum of\nthe two mapping qualities for the pair.\n- When -ed is used with -bedpe, the total edit\ndistance from the two mates is reported.\n",
                    "id": "#bedtools-bamtobed.cwl/ed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-mate1"
                    },
                    "doc": "When writing BEDPE (-bedpe) format, \nalways report mate one as the first BEDPE \"block\".\n",
                    "id": "#bedtools-bamtobed.cwl/mate1"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "Report \"split\" BAM alignments as separate BED entries.\nSplits only on N CIGAR operations.\n",
                    "id": "#bedtools-bamtobed.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-splitD"
                    },
                    "doc": "Split alignments based on N and D CIGAR operators.\nForces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/splitD"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-tag"
                    },
                    "doc": "Use other NUMERIC BAM alignment tag for BED score.\n- Default for BED is to use mapping quality.\nDisallowed with BEDPE output.\n",
                    "id": "#bedtools-bamtobed.cwl/tag"
                }
            ],
            "baseCommand": [
                "bedtools",
                "bamtobed"
            ],
            "stdout": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')",
            "id": "#bedtools-bamtobed.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')"
                    },
                    "id": "#bedtools-bamtobed.cwl/output_bedfile"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "DNase-seq - map - Filter PCR Artifacts",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_bam_files"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-bamtobed.cwl",
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "id": "#main/bedtools_bamtobed/bam"
                        }
                    ],
                    "scatter": "#main/bedtools_bamtobed/bam",
                    "out": [
                        "#main/bedtools_bamtobed/output_bedfile"
                    ],
                    "id": "#main/bedtools_bamtobed"
                },
                {
                    "run": "#windowtrimmer.cwl",
                    "in": [
                        {
                            "source": "#main/bedtools_bamtobed/output_bedfile",
                            "id": "#main/window_trimmer/input_file"
                        }
                    ],
                    "scatter": "#main/window_trimmer/input_file",
                    "out": [
                        "#main/window_trimmer/filtered_file"
                    ],
                    "id": "#main/window_trimmer"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/window_trimmer/filtered_file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/filtered_bedfile"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "doc": "Filter out reads from a BED file that are too concentrated within a base-pair window.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/windowtrimmer",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "CUTOFF\n        threshold for concentration at a single base\n        within a window to cutoff\n",
                    "id": "#windowtrimmer.cwl/cutoff"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "doc": "BED file containing the reads to be filter.",
                    "id": "#windowtrimmer.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-w"
                    },
                    "doc": "WINDOWSIZE\n        Window size threshold for trimming reads that have the same mapping start position.\n",
                    "id": "#windowtrimmer.cwl/window_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.filtered.bed')"
                    },
                    "doc": "Filtered BED file",
                    "id": "#windowtrimmer.cwl/filtered_file"
                }
            ],
            "baseCommand": "windowTrimmer.py",
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.filtered.bed')",
            "id": "#windowtrimmer.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
